%define anolis_release 1

Name:          tesseract
Version:       5.3.4
Release:       %{anolis_release}%{?dist}
Summary:       Raw OCR Engine

License:       Apache-2.0
URL:           https://github.com/tesseract-ocr/%{name}
Source0:       https://github.com/tesseract-ocr/tesseract/archive/refs/tags/%{version}.tar.gz

# Fix library name case
# Fix shared library version suffix
# Honour TESSDATA_PREFIX
# Build training libs statically
Patch0:        tesseract_cmake.patch
# Don't assume neon available on arm64/aarch64
Patch1:        tesseract_neon.patch

BuildRequires: cmake
BuildRequires: gcc-c++
BuildRequires: giflib-devel
BuildRequires: leptonica-devel
BuildRequires: libicu-devel
BuildRequires: libjpeg-turbo-devel
BuildRequires: libcurl-devel
BuildRequires: libarchive-devel
BuildRequires: libtool
BuildRequires: libtiff-devel
BuildRequires: libwebp-devel
BuildRequires: pango-devel
BuildRequires: /usr/bin/asciidoc
BuildRequires: /usr/bin/xsltproc
BuildRequires: openjpeg2-devel

Requires:      tesseract-langpack-eng


%description
A commercial quality OCR engine originally developed at HP between 1985 and
1995. In 1995, this engine was among the top 3 evaluated by UNLV. It was
open-sourced by HP and UNLV in 2005.


%package devel
Summary:       Development files for %{name}
Requires:      %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains header file for
developing applications that use %{name}.


%package tools
Summary:       Training tools for %{name}
Requires:      %{name} = %{version}-%{release}

%description tools
The %{name}-tools package contains tools for training %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
# Native build
%cmake -DCMAKE_INSTALL_LIBDIR=%{_lib} -DTESSDATA_PREFIX=%{_datadir}/%{name}
%cmake_build

# Manually build manfiles, cmake does not build them
man_xslt=http://docbook.sourceforge.net/release/xsl/current/manpages/docbook.xsl
for file in doc/*.asc; do
    asciidoc -b docbook -d manpage -o - $file | XML_CATALOG_FILES=%{_sysconfdir}/xml/catalog xsltproc --nonet -o ${file/.asc/} $man_xslt -
done

%install
%cmake_install
mkdir -p %{buildroot}%{_mandir}/{man1,man5}/
cp -a doc/*.1 %{buildroot}%{_mandir}/man1/
cp -a doc/*.5 %{buildroot}%{_mandir}/man5/

%generate_compatibility_deps

%files
%license LICENSE
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.%{version}
%{_datadir}/%{name}/
%{_mandir}/man1/tesseract.1*
%dir %{abidir}
%{abidir}/libtesseract.dump
%{abidir}/tesseract-option.list

%files devel
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/libcommon_training.a
%{_libdir}/libunicharset_training.a
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files tools
%{_bindir}/ambiguous_words
%{_bindir}/classifier_tester
%{_bindir}/cntraining
%{_bindir}/combine_lang_model
%{_bindir}/combine_tessdata
%{_bindir}/dawg2wordlist
%{_bindir}/lstmeval
%{_bindir}/lstmtraining
%{_bindir}/merge_unicharsets
%{_bindir}/mftraining
%{_bindir}/set_unicharset_properties
%{_bindir}/shapeclustering
%{_bindir}/text2image
%{_bindir}/unicharset_extractor
%{_bindir}/wordlist2dawg
%{_mandir}/man1/ambiguous_words.1*
%{_mandir}/man1/classifier_tester.1*
%{_mandir}/man1/cntraining.1*
%{_mandir}/man1/combine_lang_model.1*
%{_mandir}/man1/combine_tessdata.1*
%{_mandir}/man1/dawg2wordlist.1*
%{_mandir}/man1/lstmeval.1*
%{_mandir}/man1/lstmtraining.1*
%{_mandir}/man1/merge_unicharsets.1*
%{_mandir}/man1/mftraining.1*
%{_mandir}/man1/set_unicharset_properties.1*
%{_mandir}/man1/shapeclustering.1*
%{_mandir}/man1/text2image.1*
%{_mandir}/man1/unicharset_extractor.1*
%{_mandir}/man1/wordlist2dawg.1*
%{_mandir}/man5/unicharambigs.5.*
%{_mandir}/man5/unicharset.5.*
%{abidir}/classifier_tester-option.list
%{abidir}/cntraining-option.list
%{abidir}/combine_lang_model-option.list
%{abidir}/combine_tessdata-option.list
%{abidir}/lstmeval-option.list
%{abidir}/lstmtraining-option.list
%{abidir}/mftraining-option.list
%{abidir}/set_unicharset_properties-option.list
%{abidir}/shapeclustering-option.list
%{abidir}/text2image-option.list
%{abidir}/unicharset_extractor-option.list

%files doc
%doc README.md ChangeLog CONTRIBUTING.md AUTHORS

%changelog
* Thu Mar 20 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.3.4-1
- Update to 5.3.4 from 5.3.2
- Remove patch as the new version of tarball already includes changes
- Add patches to Don't assume neon available on arm64/aarch64
  [Patches cherry-pick from c10s. Original changelog:
  - Update to 5.3.4(5.3.4-1)]

* Wed Jul 12 2023 Funda Wang <fundawang@yeah.net> - 5.3.2-1
- New version 5.3.2

* Fri Mar 17 2023 happy_orange <songnannan@linux.alibaba.com> - 5.3.0-1
- package init from upstream
